@@ -1,8 +1,5 @@
 __author__ = 'George Ioannou'
-__version__ = (0, 3, 4, 'final', 0)
-
-from fgdb2postgis.filegdb import FileGDB
-from fgdb2postgis.postgis import PostGIS
+__version__ = (0, 3, 5, 'final', 0)
 
 def get_current_version():
     from .version import get_version
